# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_zyws_service.api_client import ApiClient
from dhicn_zyws_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TimeseriesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_historical_data_search_post(self, **kwargs):  # noqa: E501
        """历史数据查询 / historical data query  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_historical_data_search_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[GetMeasureAndSimulDataInput] get_measure_and_simul_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_historical_data_search_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_historical_data_search_post_with_http_info(self, **kwargs):  # noqa: E501
        """历史数据查询 / historical data query  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_historical_data_search_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[GetMeasureAndSimulDataInput] get_measure_and_simul_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'get_measure_and_simul_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_historical_data_search_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_measure_and_simul_data_input' in local_var_params:
            body_params = local_var_params['get_measure_and_simul_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/historical-data/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_historical_data_search_post_0(self, **kwargs):  # noqa: E501
        """历史数据查询 / historical data query  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_historical_data_search_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[GetMeasureAndSimulDataInput] get_measure_and_simul_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SearchOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_historical_data_search_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_historical_data_search_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """历史数据查询 / historical data query  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_historical_data_search_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[GetMeasureAndSimulDataInput] get_measure_and_simul_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SearchOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'get_measure_and_simul_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_historical_data_search_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_measure_and_simul_data_input' in local_var_params:
            body_params = local_var_params['get_measure_and_simul_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/historical-data/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_latest_timeseries_post(self, **kwargs):  # noqa: E501
        """根据设备编码和指标获取最新实测数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_latest_timeseries_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str is_refresh_indicators:
        :param list[LatestTimeSeriesInputV3] latest_time_series_input_v3:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[LatestTimeSeriesOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_latest_timeseries_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_latest_timeseries_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据设备编码和指标获取最新实测数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_latest_timeseries_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str is_refresh_indicators:
        :param list[LatestTimeSeriesInputV3] latest_time_series_input_v3:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[LatestTimeSeriesOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'is_refresh_indicators',
            'latest_time_series_input_v3'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_latest_timeseries_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_refresh_indicators' in local_var_params and local_var_params['is_refresh_indicators'] is not None:  # noqa: E501
            query_params.append(('isRefreshIndicators', local_var_params['is_refresh_indicators']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'latest_time_series_input_v3' in local_var_params:
            body_params = local_var_params['latest_time_series_input_v3']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/latest-timeseries', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LatestTimeSeriesOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_latest_timeseries_post_0(self, **kwargs):  # noqa: E501
        """根据设备编码和指标获取最新实测数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_latest_timeseries_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str is_refresh_indicators:
        :param list[LatestTimeSeriesInputV3] latest_time_series_input_v3:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[LatestTimeSeriesOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_latest_timeseries_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_latest_timeseries_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """根据设备编码和指标获取最新实测数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_latest_timeseries_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str is_refresh_indicators:
        :param list[LatestTimeSeriesInputV3] latest_time_series_input_v3:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[LatestTimeSeriesOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'is_refresh_indicators',
            'latest_time_series_input_v3'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_latest_timeseries_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_refresh_indicators' in local_var_params and local_var_params['is_refresh_indicators'] is not None:  # noqa: E501
            query_params.append(('isRefreshIndicators', local_var_params['is_refresh_indicators']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'latest_time_series_input_v3' in local_var_params:
            body_params = local_var_params['latest_time_series_input_v3']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/latest-timeseries', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LatestTimeSeriesOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_muiltiple_tenant_data_post(self, **kwargs):  # noqa: E501
        """获取多租户当前时刻数据，包括实测数据，mike+结果数据，west结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_muiltiple_tenant_data_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MultipleTenantDataInput] multiple_tenant_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MultipleTenantDataOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_muiltiple_tenant_data_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_muiltiple_tenant_data_post_with_http_info(self, **kwargs):  # noqa: E501
        """获取多租户当前时刻数据，包括实测数据，mike+结果数据，west结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_muiltiple_tenant_data_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MultipleTenantDataInput] multiple_tenant_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MultipleTenantDataOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'multiple_tenant_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_muiltiple_tenant_data_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'multiple_tenant_data_input' in local_var_params:
            body_params = local_var_params['multiple_tenant_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/muiltiple-tenant-data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MultipleTenantDataOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_muiltiple_tenant_data_post_0(self, **kwargs):  # noqa: E501
        """获取多租户当前时刻数据，包括实测数据，mike+结果数据，west结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_muiltiple_tenant_data_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MultipleTenantDataInput] multiple_tenant_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MultipleTenantDataOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_muiltiple_tenant_data_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_muiltiple_tenant_data_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """获取多租户当前时刻数据，包括实测数据，mike+结果数据，west结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_muiltiple_tenant_data_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MultipleTenantDataInput] multiple_tenant_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MultipleTenantDataOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'multiple_tenant_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_muiltiple_tenant_data_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'multiple_tenant_data_input' in local_var_params:
            body_params = local_var_params['multiple_tenant_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/muiltiple-tenant-data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MultipleTenantDataOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_timeseries_batch_post(self, **kwargs):  # noqa: E501
        """根据设备编码和指标获取实测数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_timeseries_batch_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool is_refresh_indicators:
        :param list[TimeseriesBatchForV3Input] timeseries_batch_for_v3_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TimeseriesBatchForV3Output]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_timeseries_batch_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_timeseries_batch_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据设备编码和指标获取实测数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_timeseries_batch_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool is_refresh_indicators:
        :param list[TimeseriesBatchForV3Input] timeseries_batch_for_v3_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TimeseriesBatchForV3Output], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'is_refresh_indicators',
            'timeseries_batch_for_v3_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_timeseries_batch_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_refresh_indicators' in local_var_params and local_var_params['is_refresh_indicators'] is not None:  # noqa: E501
            query_params.append(('isRefreshIndicators', local_var_params['is_refresh_indicators']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'timeseries_batch_for_v3_input' in local_var_params:
            body_params = local_var_params['timeseries_batch_for_v3_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/timeseries-batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TimeseriesBatchForV3Output]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_timeseries_batch_post_0(self, **kwargs):  # noqa: E501
        """根据设备编码和指标获取实测数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_timeseries_batch_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool is_refresh_indicators:
        :param list[TimeseriesBatchForV3Input] timeseries_batch_for_v3_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TimeseriesBatchForV3Output]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_timeseries_batch_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_timeseries_batch_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """根据设备编码和指标获取实测数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_timeseries_batch_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool is_refresh_indicators:
        :param list[TimeseriesBatchForV3Input] timeseries_batch_for_v3_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TimeseriesBatchForV3Output], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'is_refresh_indicators',
            'timeseries_batch_for_v3_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_timeseries_batch_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_refresh_indicators' in local_var_params and local_var_params['is_refresh_indicators'] is not None:  # noqa: E501
            query_params.append(('isRefreshIndicators', local_var_params['is_refresh_indicators']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'timeseries_batch_for_v3_input' in local_var_params:
            body_params = local_var_params['timeseries_batch_for_v3_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/timeseries-batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TimeseriesBatchForV3Output]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_muiltiple_tenant_batch_data_post(self, **kwargs):  # noqa: E501
        """获取多租户时序数据，包括实测数据，mike+结果数据，west结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_muiltiple_tenant_batch_data_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MutilpleTenantBatchDataInput] mutilple_tenant_batch_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MutilpleTenantBatchDataOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_muiltiple_tenant_batch_data_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_muiltiple_tenant_batch_data_post_with_http_info(self, **kwargs):  # noqa: E501
        """获取多租户时序数据，包括实测数据，mike+结果数据，west结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_muiltiple_tenant_batch_data_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MutilpleTenantBatchDataInput] mutilple_tenant_batch_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MutilpleTenantBatchDataOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mutilple_tenant_batch_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_muiltiple_tenant_batch_data_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mutilple_tenant_batch_data_input' in local_var_params:
            body_params = local_var_params['mutilple_tenant_batch_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/muiltiple-tenant-batch-data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MutilpleTenantBatchDataOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_muiltiple_tenant_batch_data_post_0(self, **kwargs):  # noqa: E501
        """获取多租户时序数据，包括实测数据，mike+结果数据，west结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_muiltiple_tenant_batch_data_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MutilpleTenantBatchDataInput] mutilple_tenant_batch_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MutilpleTenantBatchDataOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_muiltiple_tenant_batch_data_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_muiltiple_tenant_batch_data_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """获取多租户时序数据，包括实测数据，mike+结果数据，west结果数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_muiltiple_tenant_batch_data_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MutilpleTenantBatchDataInput] mutilple_tenant_batch_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MutilpleTenantBatchDataOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mutilple_tenant_batch_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_muiltiple_tenant_batch_data_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mutilple_tenant_batch_data_input' in local_var_params:
            body_params = local_var_params['mutilple_tenant_batch_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/muiltiple-tenant-batch-data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MutilpleTenantBatchDataOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_set_mutilple_tenant_batch_data_to_redis_post(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantBatchDataToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_batch_data_to_redis_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SetMutilpleTenantBatchDataToRedisInput] set_mutilple_tenant_batch_data_to_redis_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_set_mutilple_tenant_batch_data_to_redis_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_set_mutilple_tenant_batch_data_to_redis_post_with_http_info(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantBatchDataToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_batch_data_to_redis_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SetMutilpleTenantBatchDataToRedisInput] set_mutilple_tenant_batch_data_to_redis_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'set_mutilple_tenant_batch_data_to_redis_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_set_mutilple_tenant_batch_data_to_redis_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'set_mutilple_tenant_batch_data_to_redis_input' in local_var_params:
            body_params = local_var_params['set_mutilple_tenant_batch_data_to_redis_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/SetMutilpleTenantBatchDataToRedis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_set_mutilple_tenant_batch_data_to_redis_post_0(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantBatchDataToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_batch_data_to_redis_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SetMutilpleTenantBatchDataToRedisInput] set_mutilple_tenant_batch_data_to_redis_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_set_mutilple_tenant_batch_data_to_redis_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_set_mutilple_tenant_batch_data_to_redis_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantBatchDataToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_batch_data_to_redis_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SetMutilpleTenantBatchDataToRedisInput] set_mutilple_tenant_batch_data_to_redis_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'set_mutilple_tenant_batch_data_to_redis_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_set_mutilple_tenant_batch_data_to_redis_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'set_mutilple_tenant_batch_data_to_redis_input' in local_var_params:
            body_params = local_var_params['set_mutilple_tenant_batch_data_to_redis_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/SetMutilpleTenantBatchDataToRedis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_set_mutilple_tenant_data_to_redis_get(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantDataToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_data_to_redis_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_set_mutilple_tenant_data_to_redis_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_set_mutilple_tenant_data_to_redis_get_with_http_info(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantDataToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_data_to_redis_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_set_mutilple_tenant_data_to_redis_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/SetMutilpleTenantDataToRedis', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_set_mutilple_tenant_data_to_redis_get_0(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantDataToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_data_to_redis_get_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_set_mutilple_tenant_data_to_redis_get_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_set_mutilple_tenant_data_to_redis_get_0_with_http_info(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantDataToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_data_to_redis_get_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_set_mutilple_tenant_data_to_redis_get_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/SetMutilpleTenantDataToRedis', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_set_mutilple_tenant_indicators_to_redis_post(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantIndicatorsToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_indicators_to_redis_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MultipleTenantDataInput] multiple_tenant_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_set_mutilple_tenant_indicators_to_redis_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_set_mutilple_tenant_indicators_to_redis_post_with_http_info(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantIndicatorsToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_indicators_to_redis_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MultipleTenantDataInput] multiple_tenant_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'multiple_tenant_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_set_mutilple_tenant_indicators_to_redis_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'multiple_tenant_data_input' in local_var_params:
            body_params = local_var_params['multiple_tenant_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/SetMutilpleTenantIndicatorsToRedis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_set_mutilple_tenant_indicators_to_redis_post_0(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantIndicatorsToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_indicators_to_redis_post_0(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MultipleTenantDataInput] multiple_tenant_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_set_mutilple_tenant_indicators_to_redis_post_0_with_http_info(**kwargs)  # noqa: E501

    def api_v1_set_mutilple_tenant_indicators_to_redis_post_0_with_http_info(self, **kwargs):  # noqa: E501
        """/api/v1/SetMutilpleTenantIndicatorsToRedis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_set_mutilple_tenant_indicators_to_redis_post_0_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[MultipleTenantDataInput] multiple_tenant_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'multiple_tenant_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_set_mutilple_tenant_indicators_to_redis_post_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'multiple_tenant_data_input' in local_var_params:
            body_params = local_var_params['multiple_tenant_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/SetMutilpleTenantIndicatorsToRedis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    model-driver-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_driver_service.configuration import Configuration


class ScenarioModelStatusMessage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'app_id': 'str',
        'project_name': 'str',
        'scenario_id': 'str',
        'serial_no': 'str',
        'stage': 'ModelState',
        'process_status': 'float',
        'date_time': 'datetime',
        'has_error': 'bool',
        'message': 'str'
    }

    attribute_map = {
        'app_id': 'appId',
        'project_name': 'projectName',
        'scenario_id': 'scenarioId',
        'serial_no': 'serialNo',
        'stage': 'stage',
        'process_status': 'processStatus',
        'date_time': 'dateTime',
        'has_error': 'hasError',
        'message': 'message'
    }

    def __init__(self, app_id=None, project_name=None, scenario_id=None, serial_no=None, stage=None, process_status=None, date_time=None, has_error=None, message=None, local_vars_configuration=None):  # noqa: E501
        """ScenarioModelStatusMessage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._app_id = None
        self._project_name = None
        self._scenario_id = None
        self._serial_no = None
        self._stage = None
        self._process_status = None
        self._date_time = None
        self._has_error = None
        self._message = None
        self.discriminator = None

        self.app_id = app_id
        self.project_name = project_name
        if scenario_id is not None:
            self.scenario_id = scenario_id
        if serial_no is not None:
            self.serial_no = serial_no
        if stage is not None:
            self.stage = stage
        if process_status is not None:
            self.process_status = process_status
        if date_time is not None:
            self.date_time = date_time
        if has_error is not None:
            self.has_error = has_error
        self.message = message

    @property
    def app_id(self):
        """Gets the app_id of this ScenarioModelStatusMessage.  # noqa: E501

        计算服务id Computer service app id  # noqa: E501

        :return: The app_id of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this ScenarioModelStatusMessage.

        计算服务id Computer service app id  # noqa: E501

        :param app_id: The app_id of this ScenarioModelStatusMessage.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def project_name(self):
        """Gets the project_name of this ScenarioModelStatusMessage.  # noqa: E501

        项目名称 project name  # noqa: E501

        :return: The project_name of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this ScenarioModelStatusMessage.

        项目名称 project name  # noqa: E501

        :param project_name: The project_name of this ScenarioModelStatusMessage.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def scenario_id(self):
        """Gets the scenario_id of this ScenarioModelStatusMessage.  # noqa: E501

        方案ID scenario id  # noqa: E501

        :return: The scenario_id of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this ScenarioModelStatusMessage.

        方案ID scenario id  # noqa: E501

        :param scenario_id: The scenario_id of this ScenarioModelStatusMessage.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def serial_no(self):
        """Gets the serial_no of this ScenarioModelStatusMessage.  # noqa: E501

        序列ID serial id  # noqa: E501

        :return: The serial_no of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: str
        """
        return self._serial_no

    @serial_no.setter
    def serial_no(self, serial_no):
        """Sets the serial_no of this ScenarioModelStatusMessage.

        序列ID serial id  # noqa: E501

        :param serial_no: The serial_no of this ScenarioModelStatusMessage.  # noqa: E501
        :type: str
        """

        self._serial_no = serial_no

    @property
    def stage(self):
        """Gets the stage of this ScenarioModelStatusMessage.  # noqa: E501


        :return: The stage of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: ModelState
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """Sets the stage of this ScenarioModelStatusMessage.


        :param stage: The stage of this ScenarioModelStatusMessage.  # noqa: E501
        :type: ModelState
        """

        self._stage = stage

    @property
    def process_status(self):
        """Gets the process_status of this ScenarioModelStatusMessage.  # noqa: E501

        进度状态 Process status  # noqa: E501

        :return: The process_status of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: float
        """
        return self._process_status

    @process_status.setter
    def process_status(self, process_status):
        """Sets the process_status of this ScenarioModelStatusMessage.

        进度状态 Process status  # noqa: E501

        :param process_status: The process_status of this ScenarioModelStatusMessage.  # noqa: E501
        :type: float
        """

        self._process_status = process_status

    @property
    def date_time(self):
        """Gets the date_time of this ScenarioModelStatusMessage.  # noqa: E501

        状态更新时间 status last modification time  # noqa: E501

        :return: The date_time of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: datetime
        """
        return self._date_time

    @date_time.setter
    def date_time(self, date_time):
        """Sets the date_time of this ScenarioModelStatusMessage.

        状态更新时间 status last modification time  # noqa: E501

        :param date_time: The date_time of this ScenarioModelStatusMessage.  # noqa: E501
        :type: datetime
        """

        self._date_time = date_time

    @property
    def has_error(self):
        """Gets the has_error of this ScenarioModelStatusMessage.  # noqa: E501

        是否存在错误 if error existed  # noqa: E501

        :return: The has_error of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: bool
        """
        return self._has_error

    @has_error.setter
    def has_error(self, has_error):
        """Sets the has_error of this ScenarioModelStatusMessage.

        是否存在错误 if error existed  # noqa: E501

        :param has_error: The has_error of this ScenarioModelStatusMessage.  # noqa: E501
        :type: bool
        """

        self._has_error = has_error

    @property
    def message(self):
        """Gets the message of this ScenarioModelStatusMessage.  # noqa: E501

        包含进度信息的计算日志信息 log message with progress  # noqa: E501

        :return: The message of this ScenarioModelStatusMessage.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ScenarioModelStatusMessage.

        包含进度信息的计算日志信息 log message with progress  # noqa: E501

        :param message: The message of this ScenarioModelStatusMessage.  # noqa: E501
        :type: str
        """

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScenarioModelStatusMessage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScenarioModelStatusMessage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_result_analysis_service.api_client import ApiClient
from dhicn_result_analysis_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class RainLogApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_result_rain_get_get(self, **kwargs):  # noqa: E501
        """根据ID查询降雨记录 Get rainfall log by id  # noqa: E501

        根据ID查询降雨记录，每一场降雨记录都对应于若干个连续的自动预报方案 Query rainfall records by id. Each rainfall record corresponds to several continuous auto forecast scenarios.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_rain_get_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rain_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: QueryRainOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_rain_get_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_result_rain_get_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据ID查询降雨记录 Get rainfall log by id  # noqa: E501

        根据ID查询降雨记录，每一场降雨记录都对应于若干个连续的自动预报方案 Query rainfall records by id. Each rainfall record corresponds to several continuous auto forecast scenarios.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_rain_get_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rain_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(QueryRainOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'rain_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_rain_get_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'rain_id' in local_var_params and local_var_params['rain_id'] is not None:  # noqa: E501
            query_params.append(('rainId', local_var_params['rain_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/rain/get', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryRainOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_rain_list_by_single_time_get(self, rain_time, **kwargs):  # noqa: E501
        """查询降雨记录 Get rainfall record by time  # noqa: E501

        按时间查询降雨记录，只有时间范围包含了查询时刻的降雨记录会被返回，同时也会返回每个降雨记录对应的方案ID列表（每一场降雨记录都对应于若干个连续的自动预报方案） Query rainfall records by time, only rainfall record contain the query time will be returned, together with their associated scenario Ids.  Each rainfall record corresponds to several continuous auto forecast scenarios.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_rain_list_by_single_time_get(rain_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rain_time: 查询时刻 time (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[QueryRainOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_rain_list_by_single_time_get_with_http_info(rain_time, **kwargs)  # noqa: E501

    def api_v1_result_rain_list_by_single_time_get_with_http_info(self, rain_time, **kwargs):  # noqa: E501
        """查询降雨记录 Get rainfall record by time  # noqa: E501

        按时间查询降雨记录，只有时间范围包含了查询时刻的降雨记录会被返回，同时也会返回每个降雨记录对应的方案ID列表（每一场降雨记录都对应于若干个连续的自动预报方案） Query rainfall records by time, only rainfall record contain the query time will be returned, together with their associated scenario Ids.  Each rainfall record corresponds to several continuous auto forecast scenarios.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_rain_list_by_single_time_get_with_http_info(rain_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str rain_time: 查询时刻 time (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[QueryRainOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'rain_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_rain_list_by_single_time_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'rain_time' is set
        if self.api_client.client_side_validation and ('rain_time' not in local_var_params or  # noqa: E501
                                                        local_var_params['rain_time'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rain_time` when calling `api_v1_result_rain_list_by_single_time_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'rain_time' in local_var_params and local_var_params['rain_time'] is not None:  # noqa: E501
            query_params.append(('RainTime', local_var_params['rain_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/rain/list-by-single-time', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[QueryRainOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_rain_list_get(self, start_time, end_time, **kwargs):  # noqa: E501
        """查询降雨的记录 Query rainfall records  # noqa: E501

        按时间查询降雨记录，只有在StartTime和EndTime之间开始的降雨记录会被返回，同时也会返回每个降雨记录对应的方案ID列表（每一场降雨记录都对应于若干个连续的自动预报方案） Query rainfall records by time, only rainfall records start between StartTime and EndTime will be returned, together with their associated scenario Ids. Each rainfall record corresponds to several continuous auto forecast scenarios.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_rain_list_get(start_time, end_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 查询的开始时刻 query start time (required)
        :param str end_time: 查询的结束时刻 query end time (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[QueryRainOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_rain_list_get_with_http_info(start_time, end_time, **kwargs)  # noqa: E501

    def api_v1_result_rain_list_get_with_http_info(self, start_time, end_time, **kwargs):  # noqa: E501
        """查询降雨的记录 Query rainfall records  # noqa: E501

        按时间查询降雨记录，只有在StartTime和EndTime之间开始的降雨记录会被返回，同时也会返回每个降雨记录对应的方案ID列表（每一场降雨记录都对应于若干个连续的自动预报方案） Query rainfall records by time, only rainfall records start between StartTime and EndTime will be returned, together with their associated scenario Ids. Each rainfall record corresponds to several continuous auto forecast scenarios.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_rain_list_get_with_http_info(start_time, end_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 查询的开始时刻 query start time (required)
        :param str end_time: 查询的结束时刻 query end time (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[QueryRainOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_rain_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'start_time' is set
        if self.api_client.client_side_validation and ('start_time' not in local_var_params or  # noqa: E501
                                                        local_var_params['start_time'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `start_time` when calling `api_v1_result_rain_list_get`")  # noqa: E501
        # verify the required parameter 'end_time' is set
        if self.api_client.client_side_validation and ('end_time' not in local_var_params or  # noqa: E501
                                                        local_var_params['end_time'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `end_time` when calling `api_v1_result_rain_list_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/rain/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[QueryRainOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from dhicn_zyws_service.api.algorithm_api import AlgorithmApi
from dhicn_zyws_service.api.auto_run_result_api import AutoRunResultApi
from dhicn_zyws_service.api.calculate_orifice_height_api import CalculateOrificeHeightApi
from dhicn_zyws_service.api.configuration_api import ConfigurationApi
from dhicn_zyws_service.api.control_api import ControlApi
from dhicn_zyws_service.api.dam_gate_api import DamGateApi
from dhicn_zyws_service.api.inflow_api import InflowApi
from dhicn_zyws_service.api.model_result_api import ModelResultApi
from dhicn_zyws_service.api.orifice_opened_result_api import OrificeOpenedResultApi
from dhicn_zyws_service.api.scenario_api import ScenarioApi
from dhicn_zyws_service.api.schdule_suggestion_api import SchduleSuggestionApi
from dhicn_zyws_service.api.schedule_analysis_api import ScheduleAnalysisApi
from dhicn_zyws_service.api.system_setting_api import SystemSettingApi
from dhicn_zyws_service.api.timeseries_api import TimeseriesApi
from dhicn_zyws_service.api.urban_water_distribution_algorithm_api import UrbanWaterDistributionAlgorithmApi
from dhicn_zyws_service.api.water_delivery_principle_api import WaterDeliveryPrincipleApi

# import ApiClient
from dhicn_zyws_service.api_client import ApiClient
from dhicn_zyws_service.configuration import Configuration
from dhicn_zyws_service.exceptions import OpenApiException
from dhicn_zyws_service.exceptions import ApiTypeError
from dhicn_zyws_service.exceptions import ApiValueError
from dhicn_zyws_service.exceptions import ApiKeyError
from dhicn_zyws_service.exceptions import ApiException
# import models into sdk package
from dhicn_zyws_service.models.add_control_device_input import AddControlDeviceInput
from dhicn_zyws_service.models.add_dam_gate_scenario_input import AddDamGateScenarioInput
from dhicn_zyws_service.models.add_orifice_result_input import AddOrificeResultInput
from dhicn_zyws_service.models.add_principle_input import AddPrincipleInput
from dhicn_zyws_service.models.all_global_principles_output import AllGlobalPrinciplesOutput
from dhicn_zyws_service.models.apply_schedule_suggestions_input import ApplyScheduleSuggestionsInput
from dhicn_zyws_service.models.apply_to_auto_input import ApplyToAutoInput
from dhicn_zyws_service.models.asset_info_output import AssetInfoOutput
from dhicn_zyws_service.models.asset_rel import AssetRel
from dhicn_zyws_service.models.calculate_orifice_height_input import CalculateOrificeHeightInput
from dhicn_zyws_service.models.configuration_model import ConfigurationModel
from dhicn_zyws_service.models.control_device import ControlDevice
from dhicn_zyws_service.models.control_device_details import ControlDeviceDetails
from dhicn_zyws_service.models.control_device_output import ControlDeviceOutput
from dhicn_zyws_service.models.control_device_ts_details import ControlDeviceTsDetails
from dhicn_zyws_service.models.control_devices_input import ControlDevicesInput
from dhicn_zyws_service.models.control_devices_output import ControlDevicesOutput
from dhicn_zyws_service.models.control_devices_ts import ControlDevicesTs
from dhicn_zyws_service.models.control_devices_ts_input import ControlDevicesTsInput
from dhicn_zyws_service.models.control_devices_ts_output import ControlDevicesTsOutput
from dhicn_zyws_service.models.control_orifice_discharge_output import ControlOrificeDischargeOutput
from dhicn_zyws_service.models.control_orifice_height_output import ControlOrificeHeightOutput
from dhicn_zyws_service.models.create_plan_scenario_input import CreatePlanScenarioInput
from dhicn_zyws_service.models.dam_gate_configuration import DamGateConfiguration
from dhicn_zyws_service.models.dam_gate_configuration_input_output import DamGateConfigurationInputOutput
from dhicn_zyws_service.models.dam_gate_default_output import DamGateDefaultOutput
from dhicn_zyws_service.models.dam_gate_height_list_input import DamGateHeightListInput
from dhicn_zyws_service.models.dam_gate_info import DamGateInfo
from dhicn_zyws_service.models.dam_gate_list_output import DamGateListOutput
from dhicn_zyws_service.models.dam_gate_scenario_output import DamGateScenarioOutput
from dhicn_zyws_service.models.dam_gate_status_info import DamGateStatusInfo
from dhicn_zyws_service.models.data_result import DataResult
from dhicn_zyws_service.models.device_infos_output import DeviceInfosOutput
from dhicn_zyws_service.models.device_rel import DeviceRel
from dhicn_zyws_service.models.devices_list import DevicesList
from dhicn_zyws_service.models.factory_config import FactoryConfig
from dhicn_zyws_service.models.factory_opened_ofirice_count_output import FactoryOpenedOfiriceCountOutput
from dhicn_zyws_service.models.factory_opened_orifice_count_output import FactoryOpenedOrificeCountOutput
from dhicn_zyws_service.models.get_dam_gate_scenario_input import GetDamGateScenarioInput
from dhicn_zyws_service.models.get_measure_and_simul_data_input import GetMeasureAndSimulDataInput
from dhicn_zyws_service.models.get_orifice_contorl_result_input import GetOrificeContorlResultInput
from dhicn_zyws_service.models.get_orifice_control_result_input import GetOrificeControlResultInput
from dhicn_zyws_service.models.get_orifice_time_series_input import GetOrificeTimeSeriesInput
from dhicn_zyws_service.models.get_result_statistic_input import GetResultStatisticInput
from dhicn_zyws_service.models.get_schedule_suggestions_input import GetScheduleSuggestionsInput
from dhicn_zyws_service.models.get_schedule_suggestions_output import GetScheduleSuggestionsOutput
from dhicn_zyws_service.models.global_principles_details_input import GlobalPrinciplesDetailsInput
from dhicn_zyws_service.models.history_schedule_suggestion_record import HistoryScheduleSuggestionRecord
from dhicn_zyws_service.models.history_schedule_suggestion_record_dto import HistoryScheduleSuggestionRecordDto
from dhicn_zyws_service.models.ids_input import IdsInput
from dhicn_zyws_service.models.inlet_excel_data import InletExcelData
from dhicn_zyws_service.models.inlet_excel_download_input import InletExcelDownloadInput
from dhicn_zyws_service.models.inline_object import InlineObject
from dhicn_zyws_service.models.latest_opened_orifice_count_output import LatestOpenedOrificeCountOutput
from dhicn_zyws_service.models.latest_recommend_output import LatestRecommendOutput
from dhicn_zyws_service.models.latest_time_series_input_v3 import LatestTimeSeriesInputV3
from dhicn_zyws_service.models.latest_time_series_output import LatestTimeSeriesOutput
from dhicn_zyws_service.models.latest_warning_output import LatestWarningOutput
from dhicn_zyws_service.models.multiple_tenant_data_input import MultipleTenantDataInput
from dhicn_zyws_service.models.multiple_tenant_data_output import MultipleTenantDataOutput
from dhicn_zyws_service.models.mutilple_tenant_batch_data_input import MutilpleTenantBatchDataInput
from dhicn_zyws_service.models.mutilple_tenant_batch_data_output import MutilpleTenantBatchDataOutput
from dhicn_zyws_service.models.mutilple_tenant_data_input import MutilpleTenantDataInput
from dhicn_zyws_service.models.mutilple_tenant_data_output import MutilpleTenantDataOutput
from dhicn_zyws_service.models.node_input import NodeInput
from dhicn_zyws_service.models.node_volume_output import NodeVolumeOutput
from dhicn_zyws_service.models.orifice_contorl_result_output import OrificeContorlResultOutput
from dhicn_zyws_service.models.orifice_control_result_output import OrificeControlResultOutput
from dhicn_zyws_service.models.orifice_result_output import OrificeResultOutput
from dhicn_zyws_service.models.orifice_schedule_statistic_output import OrificeScheduleStatisticOutput
from dhicn_zyws_service.models.orifice_time_series_output import OrificeTimeSeriesOutput
from dhicn_zyws_service.models.principle_details_output import PrincipleDetailsOutput
from dhicn_zyws_service.models.principle_info import PrincipleInfo
from dhicn_zyws_service.models.processed_model_result_input import ProcessedModelResultInput
from dhicn_zyws_service.models.pump_base_configuration import PumpBaseConfiguration
from dhicn_zyws_service.models.query_boundary_input import QueryBoundaryInput
from dhicn_zyws_service.models.query_boundary_output import QueryBoundaryOutput
from dhicn_zyws_service.models.query_system_setting_default_input import QuerySystemSettingDefaultInput
from dhicn_zyws_service.models.query_system_setting_input import QuerySystemSettingInput
from dhicn_zyws_service.models.recommend_details import RecommendDetails
from dhicn_zyws_service.models.recomment_details import RecommentDetails
from dhicn_zyws_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_zyws_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_zyws_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_zyws_service.models.result_statistic_output import ResultStatisticOutput
from dhicn_zyws_service.models.result_time_series import ResultTimeSeries
from dhicn_zyws_service.models.root_object import RootObject
from dhicn_zyws_service.models.save_scenario_principle_input import SaveScenarioPrincipleInput
from dhicn_zyws_service.models.save_schedule_suggestion_input import SaveScheduleSuggestionInput
from dhicn_zyws_service.models.scenario_info import ScenarioInfo
from dhicn_zyws_service.models.scenario_principle_details_dto import ScenarioPrincipleDetailsDto
from dhicn_zyws_service.models.schedule_statistic_basic import ScheduleStatisticBasic
from dhicn_zyws_service.models.search_indicator import SearchIndicator
from dhicn_zyws_service.models.search_output import SearchOutput
from dhicn_zyws_service.models.set_mutilple_tenant_batch_data_to_redis_input import SetMutilpleTenantBatchDataToRedisInput
from dhicn_zyws_service.models.statistic_setting_input import StatisticSettingInput
from dhicn_zyws_service.models.statistic_setting_output import StatisticSettingOutput
from dhicn_zyws_service.models.string_string_key_value import StringStringKeyValue
from dhicn_zyws_service.models.system_setting_output import SystemSettingOutput
from dhicn_zyws_service.models.time_span import TimeSpan
from dhicn_zyws_service.models.timeseries_batch_for_v3_input import TimeseriesBatchForV3Input
from dhicn_zyws_service.models.timeseries_batch_for_v3_output import TimeseriesBatchForV3Output
from dhicn_zyws_service.models.ts_pairs import TsPairs
from dhicn_zyws_service.models.update_boundary_ts_input import UpdateBoundaryTsInput
from dhicn_zyws_service.models.update_system_setting_input import UpdateSystemSettingInput
from dhicn_zyws_service.models.water_delivery_principle_scenario import WaterDeliveryPrincipleScenario
from dhicn_zyws_service.models.water_volume_optim_output import WaterVolumeOptimOutput
from dhicn_zyws_service.models.weir_adjustment_parameter import WeirAdjustmentParameter
from dhicn_zyws_service.models.write_pump_configuration import WritePumpConfiguration
from dhicn_zyws_service.models.write_pump_configuration_input import WritePumpConfigurationInput




# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class HisDataSearchInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'is_search_measure': 'bool',
        'is_search_simul': 'bool',
        'library_id': 'str',
        'device_code': 'str',
        'indicator': 'str',
        'start_ts': 'datetime',
        'end_ts': 'datetime',
        'order_by': 'str',
        'sample': 'str',
        'interval': 'int'
    }

    attribute_map = {
        'is_search_measure': 'isSearchMeasure',
        'is_search_simul': 'isSearchSimul',
        'library_id': 'libraryId',
        'device_code': 'deviceCode',
        'indicator': 'indicator',
        'start_ts': 'startTs',
        'end_ts': 'endTs',
        'order_by': 'orderBy',
        'sample': 'sample',
        'interval': 'interval'
    }

    def __init__(self, is_search_measure=None, is_search_simul=None, library_id=None, device_code=None, indicator=None, start_ts=None, end_ts=None, order_by=None, sample=None, interval=None, local_vars_configuration=None):  # noqa: E501
        """HisDataSearchInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._is_search_measure = None
        self._is_search_simul = None
        self._library_id = None
        self._device_code = None
        self._indicator = None
        self._start_ts = None
        self._end_ts = None
        self._order_by = None
        self._sample = None
        self._interval = None
        self.discriminator = None

        self.is_search_measure = is_search_measure
        self.is_search_simul = is_search_simul
        self.library_id = library_id
        self.device_code = device_code
        self.indicator = indicator
        self.start_ts = start_ts
        self.end_ts = end_ts
        self.order_by = order_by
        self.sample = sample
        if interval is not None:
            self.interval = interval

    @property
    def is_search_measure(self):
        """Gets the is_search_measure of this HisDataSearchInput.  # noqa: E501

        是否查询实测历史数据  # noqa: E501

        :return: The is_search_measure of this HisDataSearchInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_search_measure

    @is_search_measure.setter
    def is_search_measure(self, is_search_measure):
        """Sets the is_search_measure of this HisDataSearchInput.

        是否查询实测历史数据  # noqa: E501

        :param is_search_measure: The is_search_measure of this HisDataSearchInput.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_search_measure is None:  # noqa: E501
            raise ValueError("Invalid value for `is_search_measure`, must not be `None`")  # noqa: E501

        self._is_search_measure = is_search_measure

    @property
    def is_search_simul(self):
        """Gets the is_search_simul of this HisDataSearchInput.  # noqa: E501

        是否查询模拟历史数据  # noqa: E501

        :return: The is_search_simul of this HisDataSearchInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_search_simul

    @is_search_simul.setter
    def is_search_simul(self, is_search_simul):
        """Sets the is_search_simul of this HisDataSearchInput.

        是否查询模拟历史数据  # noqa: E501

        :param is_search_simul: The is_search_simul of this HisDataSearchInput.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_search_simul is None:  # noqa: E501
            raise ValueError("Invalid value for `is_search_simul`, must not be `None`")  # noqa: E501

        self._is_search_simul = is_search_simul

    @property
    def library_id(self):
        """Gets the library_id of this HisDataSearchInput.  # noqa: E501

        方案类库Id,即:模拟场景;若IsSearchSimul为true,此字段必填  # noqa: E501

        :return: The library_id of this HisDataSearchInput.  # noqa: E501
        :rtype: str
        """
        return self._library_id

    @library_id.setter
    def library_id(self, library_id):
        """Sets the library_id of this HisDataSearchInput.

        方案类库Id,即:模拟场景;若IsSearchSimul为true,此字段必填  # noqa: E501

        :param library_id: The library_id of this HisDataSearchInput.  # noqa: E501
        :type: str
        """

        self._library_id = library_id

    @property
    def device_code(self):
        """Gets the device_code of this HisDataSearchInput.  # noqa: E501

        设备名称,若当前项目下Indicator有重复,设备名称必传  # noqa: E501

        :return: The device_code of this HisDataSearchInput.  # noqa: E501
        :rtype: str
        """
        return self._device_code

    @device_code.setter
    def device_code(self, device_code):
        """Sets the device_code of this HisDataSearchInput.

        设备名称,若当前项目下Indicator有重复,设备名称必传  # noqa: E501

        :param device_code: The device_code of this HisDataSearchInput.  # noqa: E501
        :type: str
        """

        self._device_code = device_code

    @property
    def indicator(self):
        """Gets the indicator of this HisDataSearchInput.  # noqa: E501

        指标 indicator  # noqa: E501

        :return: The indicator of this HisDataSearchInput.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this HisDataSearchInput.

        指标 indicator  # noqa: E501

        :param indicator: The indicator of this HisDataSearchInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and indicator is None:  # noqa: E501
            raise ValueError("Invalid value for `indicator`, must not be `None`")  # noqa: E501

        self._indicator = indicator

    @property
    def start_ts(self):
        """Gets the start_ts of this HisDataSearchInput.  # noqa: E501

        查询开始时间 start time  # noqa: E501

        :return: The start_ts of this HisDataSearchInput.  # noqa: E501
        :rtype: datetime
        """
        return self._start_ts

    @start_ts.setter
    def start_ts(self, start_ts):
        """Sets the start_ts of this HisDataSearchInput.

        查询开始时间 start time  # noqa: E501

        :param start_ts: The start_ts of this HisDataSearchInput.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and start_ts is None:  # noqa: E501
            raise ValueError("Invalid value for `start_ts`, must not be `None`")  # noqa: E501

        self._start_ts = start_ts

    @property
    def end_ts(self):
        """Gets the end_ts of this HisDataSearchInput.  # noqa: E501

        查询结束时间 end time  # noqa: E501

        :return: The end_ts of this HisDataSearchInput.  # noqa: E501
        :rtype: datetime
        """
        return self._end_ts

    @end_ts.setter
    def end_ts(self, end_ts):
        """Sets the end_ts of this HisDataSearchInput.

        查询结束时间 end time  # noqa: E501

        :param end_ts: The end_ts of this HisDataSearchInput.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and end_ts is None:  # noqa: E501
            raise ValueError("Invalid value for `end_ts`, must not be `None`")  # noqa: E501

        self._end_ts = end_ts

    @property
    def order_by(self):
        """Gets the order_by of this HisDataSearchInput.  # noqa: E501

        排序方式，ASC (升序)，DESC (降序) sort order, ASC (ASCENDING) or DESC (DESCENDING);默认是降序DESC  # noqa: E501

        :return: The order_by of this HisDataSearchInput.  # noqa: E501
        :rtype: str
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """Sets the order_by of this HisDataSearchInput.

        排序方式，ASC (升序)，DESC (降序) sort order, ASC (ASCENDING) or DESC (DESCENDING);默认是降序DESC  # noqa: E501

        :param order_by: The order_by of this HisDataSearchInput.  # noqa: E501
        :type: str
        """

        self._order_by = order_by

    @property
    def sample(self):
        """Gets the sample of this HisDataSearchInput.  # noqa: E501

        抽样类型,为空时代表不抽样,按:days hours year minutes years类型抽样  # noqa: E501

        :return: The sample of this HisDataSearchInput.  # noqa: E501
        :rtype: str
        """
        return self._sample

    @sample.setter
    def sample(self, sample):
        """Sets the sample of this HisDataSearchInput.

        抽样类型,为空时代表不抽样,按:days hours year minutes years类型抽样  # noqa: E501

        :param sample: The sample of this HisDataSearchInput.  # noqa: E501
        :type: str
        """

        self._sample = sample

    @property
    def interval(self):
        """Gets the interval of this HisDataSearchInput.  # noqa: E501

        抽样频率,如:sample=minutes,interval=5,表示按照5分钟进行抽样  # noqa: E501

        :return: The interval of this HisDataSearchInput.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this HisDataSearchInput.

        抽样频率,如:sample=minutes,interval=5,表示按照5分钟进行抽样  # noqa: E501

        :param interval: The interval of this HisDataSearchInput.  # noqa: E501
        :type: int
        """

        self._interval = interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HisDataSearchInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HisDataSearchInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    document-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_document_service.configuration import Configuration


class Version(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'major': 'int',
        'minor': 'int',
        'build': 'int',
        'revision': 'int',
        'major_revision': 'int',
        'minor_revision': 'int'
    }

    attribute_map = {
        'major': 'major',
        'minor': 'minor',
        'build': 'build',
        'revision': 'revision',
        'major_revision': 'majorRevision',
        'minor_revision': 'minorRevision'
    }

    def __init__(self, major=None, minor=None, build=None, revision=None, major_revision=None, minor_revision=None, local_vars_configuration=None):  # noqa: E501
        """Version - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._major = None
        self._minor = None
        self._build = None
        self._revision = None
        self._major_revision = None
        self._minor_revision = None
        self.discriminator = None

        if major is not None:
            self.major = major
        if minor is not None:
            self.minor = minor
        if build is not None:
            self.build = build
        if revision is not None:
            self.revision = revision
        if major_revision is not None:
            self.major_revision = major_revision
        if minor_revision is not None:
            self.minor_revision = minor_revision

    @property
    def major(self):
        """Gets the major of this Version.  # noqa: E501


        :return: The major of this Version.  # noqa: E501
        :rtype: int
        """
        return self._major

    @major.setter
    def major(self, major):
        """Sets the major of this Version.


        :param major: The major of this Version.  # noqa: E501
        :type: int
        """

        self._major = major

    @property
    def minor(self):
        """Gets the minor of this Version.  # noqa: E501


        :return: The minor of this Version.  # noqa: E501
        :rtype: int
        """
        return self._minor

    @minor.setter
    def minor(self, minor):
        """Sets the minor of this Version.


        :param minor: The minor of this Version.  # noqa: E501
        :type: int
        """

        self._minor = minor

    @property
    def build(self):
        """Gets the build of this Version.  # noqa: E501


        :return: The build of this Version.  # noqa: E501
        :rtype: int
        """
        return self._build

    @build.setter
    def build(self, build):
        """Sets the build of this Version.


        :param build: The build of this Version.  # noqa: E501
        :type: int
        """

        self._build = build

    @property
    def revision(self):
        """Gets the revision of this Version.  # noqa: E501


        :return: The revision of this Version.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Version.


        :param revision: The revision of this Version.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def major_revision(self):
        """Gets the major_revision of this Version.  # noqa: E501


        :return: The major_revision of this Version.  # noqa: E501
        :rtype: int
        """
        return self._major_revision

    @major_revision.setter
    def major_revision(self, major_revision):
        """Sets the major_revision of this Version.


        :param major_revision: The major_revision of this Version.  # noqa: E501
        :type: int
        """

        self._major_revision = major_revision

    @property
    def minor_revision(self):
        """Gets the minor_revision of this Version.  # noqa: E501


        :return: The minor_revision of this Version.  # noqa: E501
        :rtype: int
        """
        return self._minor_revision

    @minor_revision.setter
    def minor_revision(self, minor_revision):
        """Sets the minor_revision of this Version.


        :param minor_revision: The minor_revision of this Version.  # noqa: E501
        :type: int
        """

        self._minor_revision = minor_revision

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Version):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Version):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-driver-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_driver_service.configuration import Configuration


class ScenarioModelMessage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'project_name': 'str',
        'tenant_id': 'str',
        'scenario_id': 'str',
        'model_type': 'str',
        'priority': 'int',
        'model_info': 'str'
    }

    attribute_map = {
        'id': 'id',
        'project_name': 'projectName',
        'tenant_id': 'tenantId',
        'scenario_id': 'scenarioId',
        'model_type': 'modelType',
        'priority': 'priority',
        'model_info': 'modelInfo'
    }

    def __init__(self, id=None, project_name=None, tenant_id=None, scenario_id=None, model_type=None, priority=None, model_info=None, local_vars_configuration=None):  # noqa: E501
        """ScenarioModelMessage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._project_name = None
        self._tenant_id = None
        self._scenario_id = None
        self._model_type = None
        self._priority = None
        self._model_info = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.project_name = project_name
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if scenario_id is not None:
            self.scenario_id = scenario_id
        self.model_type = model_type
        if priority is not None:
            self.priority = priority
        self.model_info = model_info

    @property
    def id(self):
        """Gets the id of this ScenarioModelMessage.  # noqa: E501

        Id 与持久化在数据库中的Id一致,即queueId  # noqa: E501

        :return: The id of this ScenarioModelMessage.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ScenarioModelMessage.

        Id 与持久化在数据库中的Id一致,即queueId  # noqa: E501

        :param id: The id of this ScenarioModelMessage.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def project_name(self):
        """Gets the project_name of this ScenarioModelMessage.  # noqa: E501

        项目名称 project name  # noqa: E501

        :return: The project_name of this ScenarioModelMessage.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this ScenarioModelMessage.

        项目名称 project name  # noqa: E501

        :param project_name: The project_name of this ScenarioModelMessage.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this ScenarioModelMessage.  # noqa: E501

        租户ID  # noqa: E501

        :return: The tenant_id of this ScenarioModelMessage.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this ScenarioModelMessage.

        租户ID  # noqa: E501

        :param tenant_id: The tenant_id of this ScenarioModelMessage.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def scenario_id(self):
        """Gets the scenario_id of this ScenarioModelMessage.  # noqa: E501

        方案ID scenario id  # noqa: E501

        :return: The scenario_id of this ScenarioModelMessage.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this ScenarioModelMessage.

        方案ID scenario id  # noqa: E501

        :param scenario_id: The scenario_id of this ScenarioModelMessage.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def model_type(self):
        """Gets the model_type of this ScenarioModelMessage.  # noqa: E501

        模型类型，不同的模型类型对应不同的计算服务 model type, different model type corresponding to different compute service  <inheritdoc cref=\"T:DHI.DSS.WF.MQ.Interface.ModelSimType\" />  # noqa: E501

        :return: The model_type of this ScenarioModelMessage.  # noqa: E501
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this ScenarioModelMessage.

        模型类型，不同的模型类型对应不同的计算服务 model type, different model type corresponding to different compute service  <inheritdoc cref=\"T:DHI.DSS.WF.MQ.Interface.ModelSimType\" />  # noqa: E501

        :param model_type: The model_type of this ScenarioModelMessage.  # noqa: E501
        :type: str
        """

        self._model_type = model_type

    @property
    def priority(self):
        """Gets the priority of this ScenarioModelMessage.  # noqa: E501

        优先级：数值越大，优先级越高 priority: greater value have higher priority  # noqa: E501

        :return: The priority of this ScenarioModelMessage.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this ScenarioModelMessage.

        优先级：数值越大，优先级越高 priority: greater value have higher priority  # noqa: E501

        :param priority: The priority of this ScenarioModelMessage.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def model_info(self):
        """Gets the model_info of this ScenarioModelMessage.  # noqa: E501

        模型信息，json格式 model info in json format: {\"scenarioId\":\"\",\"tenantId\":\"\",\"templateScenarioId\":\"\"}  # noqa: E501

        :return: The model_info of this ScenarioModelMessage.  # noqa: E501
        :rtype: str
        """
        return self._model_info

    @model_info.setter
    def model_info(self, model_info):
        """Sets the model_info of this ScenarioModelMessage.

        模型信息，json格式 model info in json format: {\"scenarioId\":\"\",\"tenantId\":\"\",\"templateScenarioId\":\"\"}  # noqa: E501

        :param model_info: The model_info of this ScenarioModelMessage.  # noqa: E501
        :type: str
        """

        self._model_info = model_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScenarioModelMessage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScenarioModelMessage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class PrecisionWq(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'display_msg': 'str',
        'max_value': 'float',
        'min_value': 'float',
        'average_value': 'float',
        'deviation_value': 'float',
        'ts_data': 'list[TsPair1]'
    }

    attribute_map = {
        'code': 'code',
        'display_msg': 'displayMsg',
        'max_value': 'maxValue',
        'min_value': 'minValue',
        'average_value': 'averageValue',
        'deviation_value': 'deviationValue',
        'ts_data': 'tsData'
    }

    def __init__(self, code=None, display_msg=None, max_value=None, min_value=None, average_value=None, deviation_value=None, ts_data=None, local_vars_configuration=None):  # noqa: E501
        """PrecisionWq - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._display_msg = None
        self._max_value = None
        self._min_value = None
        self._average_value = None
        self._deviation_value = None
        self._ts_data = None
        self.discriminator = None

        self.code = code
        self.display_msg = display_msg
        if max_value is not None:
            self.max_value = max_value
        if min_value is not None:
            self.min_value = min_value
        if average_value is not None:
            self.average_value = average_value
        if deviation_value is not None:
            self.deviation_value = deviation_value
        self.ts_data = ts_data

    @property
    def code(self):
        """Gets the code of this PrecisionWq.  # noqa: E501

        指标 indicator code  # noqa: E501

        :return: The code of this PrecisionWq.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this PrecisionWq.

        指标 indicator code  # noqa: E501

        :param code: The code of this PrecisionWq.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def display_msg(self):
        """Gets the display_msg of this PrecisionWq.  # noqa: E501

        展示信息 display message  # noqa: E501

        :return: The display_msg of this PrecisionWq.  # noqa: E501
        :rtype: str
        """
        return self._display_msg

    @display_msg.setter
    def display_msg(self, display_msg):
        """Sets the display_msg of this PrecisionWq.

        展示信息 display message  # noqa: E501

        :param display_msg: The display_msg of this PrecisionWq.  # noqa: E501
        :type: str
        """

        self._display_msg = display_msg

    @property
    def max_value(self):
        """Gets the max_value of this PrecisionWq.  # noqa: E501

        最大值 maximum value  # noqa: E501

        :return: The max_value of this PrecisionWq.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this PrecisionWq.

        最大值 maximum value  # noqa: E501

        :param max_value: The max_value of this PrecisionWq.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def min_value(self):
        """Gets the min_value of this PrecisionWq.  # noqa: E501

        最小值 minimum value  # noqa: E501

        :return: The min_value of this PrecisionWq.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this PrecisionWq.

        最小值 minimum value  # noqa: E501

        :param min_value: The min_value of this PrecisionWq.  # noqa: E501
        :type: float
        """

        self._min_value = min_value

    @property
    def average_value(self):
        """Gets the average_value of this PrecisionWq.  # noqa: E501

        平均值 average value  # noqa: E501

        :return: The average_value of this PrecisionWq.  # noqa: E501
        :rtype: float
        """
        return self._average_value

    @average_value.setter
    def average_value(self, average_value):
        """Sets the average_value of this PrecisionWq.

        平均值 average value  # noqa: E501

        :param average_value: The average_value of this PrecisionWq.  # noqa: E501
        :type: float
        """

        self._average_value = average_value

    @property
    def deviation_value(self):
        """Gets the deviation_value of this PrecisionWq.  # noqa: E501

        差值 difference value  # noqa: E501

        :return: The deviation_value of this PrecisionWq.  # noqa: E501
        :rtype: float
        """
        return self._deviation_value

    @deviation_value.setter
    def deviation_value(self, deviation_value):
        """Sets the deviation_value of this PrecisionWq.

        差值 difference value  # noqa: E501

        :param deviation_value: The deviation_value of this PrecisionWq.  # noqa: E501
        :type: float
        """

        self._deviation_value = deviation_value

    @property
    def ts_data(self):
        """Gets the ts_data of this PrecisionWq.  # noqa: E501

        时间序列值 time-series data  # noqa: E501

        :return: The ts_data of this PrecisionWq.  # noqa: E501
        :rtype: list[TsPair1]
        """
        return self._ts_data

    @ts_data.setter
    def ts_data(self, ts_data):
        """Sets the ts_data of this PrecisionWq.

        时间序列值 time-series data  # noqa: E501

        :param ts_data: The ts_data of this PrecisionWq.  # noqa: E501
        :type: list[TsPair1]
        """

        self._ts_data = ts_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrecisionWq):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrecisionWq):
            return True

        return self.to_dict() != other.to_dict()
